@@ -1,7 +1,15 @@
-import asyncio,httpx,logging
+import asyncio,httpx,logging,json
 from .utils import *
 from abstract_apis import get_headers,get_response
+def get_response(obj):
+    try:
+        return obj.json()
+    except:
+        try:
+            return obj.text
+        except:
 
+            return obj
 def safe_json_dumps(obj):
     if isinstance(obj, dict):
         obj = json.dumps(obj)
@@ -31,7 +39,7 @@ def get_solcatcherSettings(getApi=False, **kwargs):
         if isinstance(apiKey, bool):
             apiKey = None
         headers = get_db_header(headers=headers, api_key=apiKey)
-    headers = bools.get('headers', headers) or get_headers()
+    headers = headers or get_headers()
     return kwargs, bools.get('solcatcherSettings'), headers, bools
 
 def get_response_option(response, option='json'):
@@ -68,10 +76,8 @@ def runSolcatcherSettings(response, solcatcherSettings):
             if isinstance(response,dict):
                 response = response.get(desired_result,response)
             usedKeys.append('getResult')
-        for key, value in solcatcherSettings.items():
-            if key not in usedKeys:
-                if key == 'getStatusCode':
-                    response = {"result": response, "status_code": status_code}
+        if 'getStatusCode' in solcatcherSettings and solcatcherSettings.get('getStatusCode') != False:
+            response = {"result": response, "status_code": status_code}
     return response
 
 async def async_call_solcatcher_ts(endpoint, *args, **kwargs):
@@ -83,6 +89,7 @@ async def async_call_solcatcher_ts(endpoint, *args, **kwargs):
     return result
 
 async def async_call_solcatcher_py(endpoint, *args, **kwargs):
+    kwargs["solcatcherSettings"] = kwargs.get("solcatcherSettings") or {"getResponse":True,"getResult":True}
     kwargs, solcatcherSettings, headers, bools = get_solcatcherSettings(**kwargs)
     payload = get_payload(*args, **kwargs)
     url = getSolcatcherPairCatchUrl(endpoint=endpoint)
@@ -91,6 +98,7 @@ async def async_call_solcatcher_py(endpoint, *args, **kwargs):
     return result
 
 async def async_call_solcatcher_db(endpoint, *args, **kwargs):
+    kwargs["solcatcherSettings"] = kwargs.get("solcatcherSettings") or {"getResponse":True,"getResult":True}
     kwargs, solcatcherSettings, headers, bools = get_solcatcherSettings(True, **kwargs)
     payload = get_payload(*args, **kwargs)
     url = getSolcatcherDbCalls(endpoint=endpoint)
@@ -149,6 +157,7 @@ async def async_make_rate_limited_call(method, params, url_1_only=True, url_2_on
         if solcatcherSettings.get('getStatusCode'):
             if isinstance(result,dict):
                 status_code = result.get('status_code')
+                results = result.get('result')
                 if status_code and status_code != 429:
                     if ogsettings.get('getStatusCode'):
                         return result
@@ -181,3 +190,5 @@ def call_solcatcher_ts(endpoint,*args,**kwargs):
 def call_solcatcher_db(endpoint,*args, **kwargs):
     return asyncio.run(async_call_solcatcher_db(endpoint,*args,**kwargs))
 
+
+
